# coding: utf-8

"""
Abdm Abha

Abdm SDK for abha

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictStr,
    field_validator,
)
from typing import Any, ClassVar, Dict, List, Optional
from typing import Set
from typing_extensions import Self


class CreateHealthIdWithPreVerified200Response(BaseModel):
    """
    CreateHealthIdWithPreVerified200Response
    """  # noqa: E501

    auth_methods: Optional[List[StrictStr]] = Field(
        default=None, description="Based on authMethods", alias="authMethods"
    )
    day_of_birth: Optional[StrictStr] = Field(default=None, alias="dayOfBirth")
    district_code: Optional[StrictStr] = Field(default=None, alias="districtCode")
    district_name: Optional[StrictStr] = Field(default=None, alias="districtName")
    email: Optional[StrictStr] = None
    first_name: Optional[StrictStr] = Field(default=None, alias="firstName")
    gender: Optional[StrictStr] = None
    health_id: Optional[StrictStr] = Field(default=None, alias="healthId")
    health_id_number: Optional[StrictStr] = Field(default=None, alias="healthIdNumber")
    kyc_photo: Optional[StrictStr] = Field(
        default=None, description="Encoded with Base 64", alias="kycPhoto"
    )
    last_name: Optional[StrictStr] = Field(default=None, alias="lastName")
    middle_name: Optional[StrictStr] = Field(default=None, alias="middleName")
    mobile: Optional[StrictStr] = None
    month_of_birth: Optional[StrictStr] = Field(default=None, alias="monthOfBirth")
    name: Optional[StrictStr] = None
    new: Optional[StrictBool] = None
    profile_photo: Optional[StrictStr] = Field(
        default=None, description="Encoded with Base 64", alias="profilePhoto"
    )
    refresh_token: Optional[StrictStr] = Field(
        default=None, description="JWT Bearer Token", alias="refreshToken"
    )
    state_code: Optional[StrictStr] = Field(default=None, alias="stateCode")
    state_name: Optional[StrictStr] = Field(default=None, alias="stateName")
    tags: Optional[Dict[str, StrictStr]] = None
    token: Optional[StrictStr] = Field(default=None, description="JWT Bearer Token")
    year_of_birth: Optional[StrictStr] = Field(default=None, alias="yearOfBirth")
    __properties: ClassVar[List[str]] = [
        "authMethods",
        "dayOfBirth",
        "districtCode",
        "districtName",
        "email",
        "firstName",
        "gender",
        "healthId",
        "healthIdNumber",
        "kycPhoto",
        "lastName",
        "middleName",
        "mobile",
        "monthOfBirth",
        "name",
        "new",
        "profilePhoto",
        "refreshToken",
        "stateCode",
        "stateName",
        "tags",
        "token",
        "yearOfBirth",
    ]

    @field_validator("auth_methods")
    def auth_methods_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                ["AADHAAR_OTP", "MOBILE_OTP", "PASSWORD", "DEMOGRAPHICS", "AADHAAR_BIO"]
            ):
                raise ValueError(
                    "each list item must be one of ('AADHAAR_OTP', 'MOBILE_OTP', 'PASSWORD', 'DEMOGRAPHICS', 'AADHAAR_BIO')"
                )
        return value

    @field_validator("gender")
    def gender_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(["M", "F", "O", "U"]):
            raise ValueError("must be one of enum values ('M', 'F', 'O', 'U')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateHealthIdWithPreVerified200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateHealthIdWithPreVerified200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "authMethods": obj.get("authMethods"),
                "dayOfBirth": obj.get("dayOfBirth"),
                "districtCode": obj.get("districtCode"),
                "districtName": obj.get("districtName"),
                "email": obj.get("email"),
                "firstName": obj.get("firstName"),
                "gender": obj.get("gender"),
                "healthId": obj.get("healthId"),
                "healthIdNumber": obj.get("healthIdNumber"),
                "kycPhoto": obj.get("kycPhoto"),
                "lastName": obj.get("lastName"),
                "middleName": obj.get("middleName"),
                "mobile": obj.get("mobile"),
                "monthOfBirth": obj.get("monthOfBirth"),
                "name": obj.get("name"),
                "new": obj.get("new"),
                "profilePhoto": obj.get("profilePhoto"),
                "refreshToken": obj.get("refreshToken"),
                "stateCode": obj.get("stateCode"),
                "stateName": obj.get("stateName"),
                "tags": obj.get("tags"),
                "token": obj.get("token"),
                "yearOfBirth": obj.get("yearOfBirth"),
            }
        )
        return _obj
